:::{image} _static/logo.svg
:class: only-light
:alt: Plopp
:width: 60%
:align: center
:::

:::{image} _static/logo-dark.svg
:class: only-dark
:alt: Plopp
:width: 60%
:align: center
:::

#

<span style="font-size:1.2em;font-style:italic;color:#5a5a5a">
    Visualization library for the <a href="https://scipp.github.io">Scipp</a> project.
    <br><br><br>
</span>

Head over to the [Getting started](./user-guide/index.md#getting-started) section of the user guide for an introduction to Plopp.

:::{include} user-guide/getting-started/installation.md
:heading-offset: 1
:::

## Get in touch

- If you have questions that are not answered by these documentation pages, ask on [GitHub discussions](https://github.com/scipp/plopp/discussions). Please include a self-contained reproducible example if possible.
- Report bugs (including unclear, missing, or wrong documentation!), suggest features or view the source code [on GitHub](https://github.com/scipp/plopp).

```{toctree}
---
hidden:
---

user-guide/index
gallery/index
api-reference/index
developer/index
about/index
```
